﻿using Microsoft.AspNetCore.Mvc;
using PetCompanion.Repositories;

namespace PetCompanion.Controllers
{
    public class GameDataController : BaseController
    {
        private readonly GameItemsRepository gameItemsRepository;
        private readonly ILogger<InventoryController> logger;

        public GameDataController(
            ILogger<InventoryController> logger,
            GameItemsRepository gameItemsRepository)
        {
            this.logger = logger;
            this.gameItemsRepository = gameItemsRepository;
        }

        [HttpGet("item/{itemId}")]
        public IActionResult GetItemInfo(int itemId)
        {
            try
            {
                return Ok(gameItemsRepository.GetById(itemId));
            }
            catch (Exception ex)
            {
                return BadRequest(ex.Message);
            }
        }

        [HttpGet("item/{itemId}/icon")]
        public IActionResult GetItemIcon(int itemId)
        {
            try
            {
                var iconBytes = gameItemsRepository.GetItemIcon(itemId);
                return File(iconBytes, "image/png");
            }
            catch (Exception ex)
            {
                return BadRequest(ex.Message);
            }
        }
    }
}
